#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-5yy3eOFYYue9EtS62IthoF
key:                  http-conduit-2.3.9.1-5yy3eOFYYue9EtS62IthoF
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  b6104f60e6cfe18c4f2908edefe92b9c
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-5yy3eOFYYue9EtS62IthoF
depends:
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7
    attoparsec-aeson-2.2.2.0-D5qY4O0Y7ug3DT7d3V7E7w base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT
    conduit-extra-1.3.8-Ck6pOXJmJPw7MIsaJ1VnN1
    http-client-0.7.19-EUgGdw3KTvRKxRF4wbGFhk
    http-client-tls-0.3.6.4-H3zfj6u59LA6yzNQrvZrZx
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa mtl-2.3.1
    resourcet-1.3.0-Cuj4zJihfYr1ci2ntaM4ld transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

